# Security Policy

This document outlines security procedures and general policies for the `cosmpy` project.

## Supported Versions

The following table shows which versions of `cosmpy` are currently being supported with security updates.

| Version   | Supported          |
| --------- | ------------------ |
| `< 1.0.0` | :white_check_mark: |

## Reporting a Vulnerability

The `cosmpy` team and community take all security bugs in `cosmpy` seriously. We appreciate your efforts and responsible disclosure and will make every effort to acknowledge your contributions.

Report security bugs by emailing `developer@fetch.ai`.

The lead maintainer will acknowledge your email within 48 hours, and will send a more detailed response within 48 hours indicating the next steps in handling your report. After the initial reply to your report, the security team will endeavour to keep you informed of the progress towards a fix and full announcement, and may ask for additional information or guidance.

Report security bugs in third-party modules to the person or team maintaining the module.

## Disclosure Policy

When the security team receives a security bug report, they will assign it to a primary handler. This person will coordinate the fix and release process, involving the following steps:

- Confirm the problem and determine the affected versions.
- Audit code to find any potential similar problems.
- Prepare fixes for all releases still under maintenance. These fixes will be released as fast as possible to PyPI.

## Comments on this Policy

If you have suggestions on how this process could be improved please submit a pull request.
